<template>
  <b-modal
    size="md"
    :title="title"
    ref="myModalRef"
    ok-title="保存"
    @ok="handleOk"
    @cancel="clearName"
    cancel-title="取消"
    :hide-header="false"
    :hide-footer="!isShowFooter"
  >
    <div>
      <!-- <h4>{{title}}</h4> -->
      <el-form
        :model="addForm"
        label-position="right"
        :rules="rules"
        ref="addForm"
        label-width="130px"
      >
        <el-form-item label="公网IP地址：" prop="publicIp">
          <el-input v-model="addForm.publicIp" placeholder="请输公网IP地址" :disabled="isDisabled"></el-input>
        </el-form-item>
        <el-form-item label="公网端口：" prop="publicPort">
          <el-input v-model="addForm.publicPort" placeholder="请输公网端口" :disabled="isDisabled"></el-input>
        </el-form-item>
        <div class="text-right mt-2 pt-4 border-top">
          <b-button size="md" class="mx-2" @click="hideModel">取消</b-button>
          <b-button variant="primary" class="mx-2" size="md" @click="submitForm('addForm')">保存</b-button>
        </div>
      </el-form>
    </div>
  </b-modal>
</template>

<script>
import {
  Table,
  TableColumn,
  Col,
  Form,
  FormItem,
  Input,
  Checkbox,
  Radio,
  RadioGroup,
  Select,
  Option
} from 'element-ui'
import { setPublicUrl } from '@/server/home.js'
export default {
  props: {
    title: String,
    item: Object,
    isShowFooter: {
      default: false
    }
  },
  components: {
    Table,
    TableColumn,
    elCol: Col,
    elForm: Form,
    elFormItem: FormItem,
    elInput: Input,
    elCheckbox: Checkbox,
    elRadio: Radio,
    elRadioGroup: RadioGroup,
    elSelect: Select,
    elOption: Option
  },
  data() {
    var isIP = (rule, value, callback) => {
      if (!value) {
        return callback(new Error('IP必填'))
      }
      /* 端口 /^([0-9]|[1-9]\d|[1-9]\d{2}|[1-9]\d{3}|[1-5]\d{4}|6[0-4]\d{3}|65[0-4]\d{2}|655[0-2]\d|6553[0-5])$/ */
      const reg = /^(\d{1,2}|1\d\d|2[0-4]\d|25[0-5])\.(\d{1,2}|1\d\d|2[0-4]\d|25[0-5])\.(\d{1,2}|1\d\d|2[0-4]\d|25[0-5])\.(\d{1,2}|1\d\d|2[0-4]\d|25[0-5])$/
      if (value && !reg.test(value)) {
        return callback(new Error('IP不合法'))
      } else {
        callback()
      }
    }
    return {
      name: '',
      typeList: [],
      addForm: {
        id: '',
        publicIp: '',
        publicPort: ''
      },
      rules: {
        publicIp: [{ required: true, validator: isIP, trigger: 'blur' }],
        publicPort: [
          { required: true, message: '端口必填', trigger: 'blur' },
          {
            pattern: /^([0-9]|[1-9]\d{1,3}|[1-5]\d{4}|6[0-5]{2}[0-3][0-5])$/,
            message: '端口号必须是0-65535的数字',
            trigger: 'blur'
          }
        ]
      }
    }
  },
  computed: {
    isDisabled() {
      return this.$route.query.type === 'check'
    },
    isCamera() {
      return false
    }
  },
  methods: {
    // * 打开modal
    showModel(data) {
      this.$refs.myModalRef.show()
      if (data) {
        this.$nextTick(() => {
          this.reView(data)
        })
      }
    },
    hideModel() {
      this.$refs.myModalRef.hide()
    },
    /* 接口 start */
    async setPublicUrl(json) {
      const res = await setPublicUrl(json)
      if (res.success && res.code === 200 && res.data) {
        /* 成功操作 */
        this.$emit('submit')
        this.hideModel()
        this.$toast({
          type: 'success',
          message: res && res.msg ? res.msg : '配置地址成功'
        })
      } else {
        this.$toast({
          type: 'error',
          message: res && res.msg ? res.msg : '配置地址失败！'
        })
      }
    },
    /* 接口 end */
    submitForm(formName) {
      this.$refs[formName].validate(valid => {
        if (valid) {
          this.setPublicUrl(this.addForm)
        } else {
          console.log('保存接口，参数不合法!!')
          return false
        }
      })
    },

    // 回显
    reView(item) {
      console.log(item, '--回显--')
      const { id = '', publicIp = '', publicPort = '' } = item
      this.resetForm('addForm')
      this.addForm = {
        id,
        publicIp,
        publicPort
      }
    },
    // * 提交表单
    handleOk(e) {
      e.preventDefault()
      if (!this.name) {
        this.$toast({
          type: 'warning',
          message: '请输入角色名称'
        })
        return
      }
      this.$emit('submit', this.name, this.item ? this.item.id : '')
    },
    // * 取消
    clearName() {},
    resetForm(formName) {
      this.$refs[formName].resetFields()
    }
  }
}
</script>
<style lang="scss" >
.colony-table {
  .el-table td {
    padding: 6px !important;
  }
  .has-gutter th {
    padding: 2px !important;
    background: transparent !important;
  }
  .el-table td,
  .el-table th.is-leaf {
    border-bottom: none !important;
  }
  .el-table::before {
    background-color: transparent;
  }
}
</style>
